@@ -45,6 +45,9 @@ extern "C" {
 #include <iomanip>
 #include <sstream>
 
+#include <Lum/Def/Menu.h>
+#include <Lum/Def/MultiView.h>
+
 #include <Lum/OS/Probe.h>
 #include <Lum/OS/Thread.h>
 
@@ -70,7 +73,6 @@ extern "C" {
 #include <Lum/Dialog.h>
 #include <Lum/Label.h>
 #include <Lum/LED.h>
-#include <Lum/Menu.h>
 #include <Lum/Panel.h>
 #include <Lum/PercentBar.h>
 #include <Lum/Tab.h>
@@ -761,11 +763,10 @@ public:
     Lum::Model::HeaderRef headerModel;
     Lum::Label            *label;
     Lum::Panel            *hPanel;
-    Lum::Tab              *tab;
     Lum::Table            *table;
     Compass               *compass;
 
-    tab=Lum::Tab::Create(true,true);
+    Lum::Def::MultiView multiView(Lum::Def::Desc(L"GPSJinni"));
 
     hPanel=Lum::HPanel::Create(true,true);
 
@@ -787,7 +788,9 @@ public:
     label->AddLabel(L"Climb:",CreateTextValue(climb,10));
     hPanel->Add(label);
 
-    tab->Add(L"General",hPanel);
+    multiView.AddView(Lum::Def::MultiView::View(0,
+                                                Lum::Def::Desc(L"General"),
+                                                hPanel));
 
     headerModel=new Lum::Model::HeaderImpl();
     headerModel->AddColumn(L"Id",Lum::Base::Size::stdCharWidth,3);
@@ -801,23 +804,28 @@ public:
     table->SetModel(satellites);
     table->GetTableView()->SetAutoFitColumns(true);
 
-    tab->Add(L"Satellites",table);
+    multiView.AddView(Lum::Def::MultiView::View(1,
+                                                Lum::Def::Desc(L"Satelites"),
+                                                table));
 
     compass=new Compass();
     compass->SetFlex(true,true);
     compass->SetModel(direction);
 
-    tab->Add(L"Compass",compass);
+    multiView.AddView(Lum::Def::MultiView::View(2,
+                                                Lum::Def::Desc(L"Compass"),
+                                                compass));
 
-    tab->Add(L"Diagrams",
-             Lum::VPanel::Create(true,true)
-             ->Add(Lum::Text::Create(L"Speed (m/s)"))
-             ->AddSpace()
-             ->Add(Lum::View::Create(TimeLine::Create(speedStream,true,true),true,true))
-             ->AddSpace()
-             ->Add(Lum::Text::Create(L"Altitude (m)"))
-             ->AddSpace()
-             ->Add(Lum::View::Create(TimeLine::Create(altitudeStream,true,true),true,true)));
+    multiView.AddView(Lum::Def::MultiView::View(3,
+                                                Lum::Def::Desc(L"Diagrams"),
+                                                Lum::VPanel::Create(true,true)
+                                                ->Add(Lum::Text::Create(L"Speed (m/s)"))
+                                                ->AddSpace()
+                                                ->Add(Lum::View::Create(TimeLine::Create(speedStream,true,true),true,true))
+                                                ->AddSpace()
+                                                ->Add(Lum::Text::Create(L"Altitude (m)"))
+                                                ->AddSpace()
+                                                ->Add(Lum::View::Create(TimeLine::Create(altitudeStream,true,true),true,true))));
 
     headerModel=new Lum::Model::HeaderImpl();
     headerModel->AddColumn(L"Track",Lum::Base::Size::stdCharWidth,10,true);
@@ -831,43 +839,50 @@ public:
     table->SetSelection(trackSelection);
     table->GetTableView()->SetAutoFitColumns(true);
 
-    tab->Add(L"Tracking",
-             Lum::VPanel::Create(true,true)
-             ->Add(Lum::HPanel::Create(true,false)
-                   ->Add(Lum::Button::Create(L"Record",
-                                             Lum::OS::Theme::imageMediaRecord,
-                                             startTrackingAction,
-                                             Lum::Button::typeIcon))
-                   ->Add(Lum::Button::Create(L"Stop",
-                                             Lum::OS::Theme::imageMediaStop,
-                                             stopTrackingAction,
-                                             Lum::Button::typeIcon))
-                   ->AddSpace(true)
-                    ->Add(new Lum::LED(tracking))
-                    ->AddSpace(true)
-                   ->Add(Lum::Button::Create(L"_Delete",
-                                             Lum::OS::Theme::imageRemove,
-                                             deleteTrackAction,
-                                             Lum::Button::typeIcon))
-                   ->Add(Lum::Button::Create(L"_Export",
-                                             Lum::OS::Theme::imageSave,
-                                             exportTrackAction,
-                                             Lum::Button::typeIcon)))
-             ->AddSpace()
-             ->Add(table));
-    SetMain(tab);
+    multiView.AddView(Lum::Def::MultiView::View(4,
+                                                Lum::Def::Desc(L"Tracking"),
+                                                Lum::VPanel::Create(true,true)
+                                                ->Add(Lum::HPanel::Create(true,false)
+                                                      ->Add(Lum::Button::Create(L"Record",
+                                                                                Lum::OS::Theme::imageMediaRecord,
+                                                                                startTrackingAction,
+                                                                                Lum::Button::typeIcon))
+                                                      ->Add(Lum::Button::Create(L"Stop",
+                                                                                Lum::OS::Theme::imageMediaStop,
+                                                                                stopTrackingAction,
+                                                                                Lum::Button::typeIcon))
+                                                      ->AddSpace(true)
+                                                       ->Add(new Lum::LED(tracking))
+                                                       ->AddSpace(true)
+                                                      ->Add(Lum::Button::Create(L"_Delete",
+                                                                                Lum::OS::Theme::imageRemove,
+                                                                                deleteTrackAction,
+                                                                                Lum::Button::typeIcon))
+                                                      ->Add(Lum::Button::Create(L"_Export",
+                                                                                Lum::OS::Theme::imageSave,
+                                                                                exportTrackAction,
+                                                                                Lum::Button::typeIcon)))
+                                                ->AddSpace()
+                                                ->Add(table)));
 
-    Lum::MenuDesc *menu=new Lum::MenuDesc();
+    Lum::Def::Menu *preMenu=Lum::Def::Menu::Create();
 
-    menu
-      ->AddMenuItemSub(_ld(menuProject))
-        ->AddMenuItemAction(_ld(menuProjectQuit),Lum::OS::qualifierControl,L"q",GetClosedAction());
-    menu
-      ->AddMenuItemSub(_ld(menuHelp))
-        ->AddMenuItemAction(_ld(menuHelpHelp),NULL)
-        ->AddMenuItemAction(_ld(menuHelpAbout),aboutAction);
+    preMenu
+      ->GroupProject()
+        ->ActionQuit(GetClosedAction())
+      ->End();
 
-    SetMenu(menu);
+    Lum::Def::Menu *postMenu=Lum::Def::Menu::Create();
+
+    postMenu
+      ->GroupHelp()
+        //->ActionHelp()
+        ->ActionAbout(aboutAction)
+      ->End();
+
+    multiView.SetMenu(preMenu,postMenu);
+
+    Lum::OS::display->GetBehaviour()->ApplyMultiViewDlg(this,multiView);
 
     Dialog::PreInit();
   }
